/* BdfServer_API - Copyright (c) 2020-2021 Vincent Calame - Exemole
 * Logiciel libre donné sous triple licence :
 * 1) selon les termes de la CeCILL V2
 * 2) selon les termes de l’EUPL V.1.1
 * 3) selon les termes de la GNU GPLv3
 * Voir le fichier licences.txt
 */


package fr.exemole.bdfserver.api.instruction;

import fr.exemole.bdfserver.api.BdfServer;
import fr.exemole.bdfserver.api.roles.PermissionSummary;
import fr.exemole.bdfserver.api.users.BdfUser;
import fr.exemole.bdfserver.tools.roles.PermissionUtils;
import java.util.Locale;
import net.fichotheque.Fichotheque;
import net.fichotheque.Subset;
import net.mapeadores.util.localisation.Lang;
import net.mapeadores.util.localisation.MessageLocalisation;
import net.mapeadores.util.logging.CommandMessage;
import net.mapeadores.util.logging.LogUtils;


/**
 *
 * @author Vincent Calame
 */
public interface BdfParameters {

    public BdfServer getBdfServer();

    public BdfUser getBdfUser();

    public PermissionSummary getPermissionSummary();

    public default Fichotheque getFichotheque() {
        return getBdfServer().getFichotheque();
    }

    public default Lang getWorkingLang() {
        return getBdfUser().getWorkingLang();
    }

    public default Locale getFormatLocale() {
        return getBdfUser().getFormatLocale();
    }

    public default MessageLocalisation getMessageLocalisation() {
        return getBdfServer().getL10nManager().getMessageLocalisation(getBdfUser().getLangPreference());
    }

    public default void checkGlobalAdmin() throws PermissionBdfInstructionException {
        if (!getBdfServer().getPermissionManager().isAdmin(getBdfUser().getRedacteur())) {
            CommandMessage commandMessage = LogUtils.error("_ error.permission.admin");
            PermissionBdfInstructionException permissionException = new PermissionBdfInstructionException(commandMessage);
            throw permissionException;
        }
    }

    public default void checkSubsetAdmin(Subset subset) throws PermissionBdfInstructionException {
        PermissionUtils.checkSubsetAdmin(getPermissionSummary(), subset);
    }

    public default void checkSubsetAccess(Subset subset) throws PermissionBdfInstructionException {
        PermissionUtils.checkSubsetAccess(getPermissionSummary(), subset);
    }

}
