/* BdfServer - Copyright (c) 2022 Vincent Calame - Exemole
 * Logiciel libre donné sous triple licence :
 * 1) selon les termes de la CeCILL V2
 * 2) selon les termes de l’EUPL V.1.1
 * 3) selon les termes de la GNU GPLv3
 * Voir le fichier licences.txt
 */


package fr.exemole.bdfserver.tools.exportation.transformation.defaulttemplates;

import fr.exemole.bdfserver.api.BdfServer;
import fr.exemole.bdfserver.api.storage.StorageContent;
import fr.exemole.bdfserver.api.storage.TemplateStorage;
import fr.exemole.bdfserver.tools.storage.StorageUtils;
import java.io.IOException;
import java.util.ArrayList;
import java.util.List;
import net.fichotheque.exportation.transformation.TemplateDef;
import net.fichotheque.exportation.transformation.TemplateKey;
import net.fichotheque.exportation.transformation.TransformationKey;
import net.fichotheque.tools.exportation.transformation.TemplateDefBuilder;
import net.mapeadores.util.xml.XsltWriter;


/**
 *
 * @author Vincent Calame
 */
class XsltFragmentUnit {

    private XsltFragmentUnit() {

    }

    static TemplateStorage.Unit build(BdfServer bdfServer, TemplateKey templateKey) {
        if (!templateKey.isSimpleTemplate()) {
            throw new IllegalArgumentException("templateKey is not a simple template key");
        }
        TransformationKey transformationKey = templateKey.getTransformationKey();
        if (!transformationKey.equals(TransformationKey.SECTION_TRANSFORMATIONKEY)) {
            throw new IllegalArgumentException("Only for section transformationKey");
        }
        TemplateDef templateDef = TemplateDefBuilder.init(templateKey).toTemplateDef();
        String xslt = getTransformationXslt();
        List<StorageContent> list = new ArrayList<StorageContent>();
        list.add(StorageUtils.toStorageContent("transformer.xsl", xslt));
        List<StorageContent> finalList = StorageUtils.wrap(list.toArray(new StorageContent[list.size()]));
        return new DefaultTemplateStorageUnit("xslt", templateKey, templateDef, finalList);
    }

    private static String getTransformationXslt() {
        StringBuilder buf = new StringBuilder();
        XsltWriter xsltWriter = new XsltWriter();
        xsltWriter.setAppendable(buf);
        xsltWriter.setIndentLength(0);
        try {
            xsltWriter.appendXMLDeclaration();
            xsltWriter.openXslStyleSheet();
            xsltWriter.addXslInclude("bdf://this/xslt/" + "section" + "_fragment.xsl");
            xsltWriter.closeXslStyleSheet();
        } catch (IOException ioe) {
        }
        return buf.toString();
    }

}
