/* BdfServer_Commands - Copyright (c) 2015-2021 Vincent Calame - Exemole
 * Logiciel libre donné sous triple licence :
 * 1) selon les termes de la CeCILL V2
 * 2) selon les termes de l’EUPL V.1.1
 * 3) selon les termes de la GNU GPLv3
 * Voir le fichier licences.txt
 */


package fr.exemole.bdfserver.commands.addenda;

import fr.exemole.bdfserver.api.BdfServer;
import fr.exemole.bdfserver.api.instruction.BdfInstructionException;
import fr.exemole.bdfserver.api.interaction.Domains;
import fr.exemole.bdfserver.commands.AbstractPhrasesCommand;
import net.fichotheque.addenda.Addenda;
import net.fichotheque.addenda.metadata.AddendaMetadataEditor;
import net.mapeadores.util.request.RequestMap;


/**
 *
 * @author Vincent Calame
 */
public class AddendaPhrasesCommand extends AbstractPhrasesCommand {

    public final static String COMMANDNAME = "AddendaPhrases";
    public final static String COMMANDKEY = "_ ADD-02";
    private Addenda addenda;

    public AddendaPhrasesCommand(BdfServer bdfServer, RequestMap requestMap) {
        super(bdfServer, requestMap);
    }

    @Override
    public boolean needSynchronisation() {
        return true;
    }

    @Override
    protected void doCommand() throws BdfInstructionException {
        initEditSession(Domains.ADDENDA + "/" + COMMANDNAME);
        AddendaMetadataEditor addendaMetadataEditor = editSession.getFichothequeEditor().getAddendaEditor(addenda.getSubsetKey()).getAddendaMetadataEditor();
        boolean done = false;
        if (update(addendaMetadataEditor)) {
            done = true;
        }
        if (done) {
            setDone("_ done.addenda.addendaphrases");
        }
        putResultObject(ADDENDA_OBJ, addenda);
    }

    @Override
    protected boolean checkParameters() throws BdfInstructionException {
        addenda = getMandatoryAddenda();
        checkSubsetAdmin(addenda);
        boolean done = checkPhrasesParameters();
        return done;
    }

}
