/* BdfServer_Commands - Copyright (c) 2010-2021 Vincent Calame - Exemole
 * Logiciel libre donné sous triple licence :
 * 1) selon les termes de la CeCILL V2
 * 2) selon les termes de l’EUPL V.1.1
 * 3) selon les termes de la GNU GPLv3
 * Voir le fichier licences.txt
 */


package fr.exemole.bdfserver.commands.album;

import fr.exemole.bdfserver.api.BdfServer;
import fr.exemole.bdfserver.api.instruction.BdfInstructionException;
import fr.exemole.bdfserver.api.interaction.Domains;
import fr.exemole.bdfserver.tools.instruction.AbstractBdfCommand;
import fr.exemole.bdfserver.tools.instruction.BdfInstructionUtils;
import net.fichotheque.album.Album;
import net.fichotheque.album.metadata.AlbumDim;
import net.fichotheque.album.metadata.AlbumMetadataEditor;
import net.fichotheque.utils.AlbumUtils;
import net.mapeadores.util.request.RequestMap;


/**
 *
 * @author Vincent Calame
 */
public class AlbumDimChangeCommand extends AbstractBdfCommand {

    public final static String COMMANDNAME = "AlbumDimChange";
    public final static String COMMANDKEY = "_ ALB-04";
    public final static String ALBUMDIM_WIDTH_PARAMNAME = "albumdimwidth";
    public final static String ALBUMDIM_HEIGHT_PARAMNAME = "albumdimheight";
    private AlbumDim albumDim;
    private int width = 0;
    private int height = 0;

    public AlbumDimChangeCommand(BdfServer bdfServer, RequestMap requestMap) {
        super(bdfServer, requestMap);
    }

    @Override
    public boolean needSynchronisation() {
        return true;
    }

    @Override
    protected void doCommand() throws BdfInstructionException {
        initEditSession(Domains.ALBUM + "/" + COMMANDNAME);
        Album album = albumDim.getAlbumMetadata().getAlbum();
        AlbumMetadataEditor albumMetadataEditor = editSession.getFichothequeEditor().getAlbumEditor(album.getSubsetKey()).getAlbumMetadataEditor();
        albumMetadataEditor.setDim(albumDim, width, height);
        putResultObject(ALBUM_OBJ, album);
        putResultObject(ALBUMDIM_OBJ, albumDim);
        setDone("_ done.album.albumdimchange", albumDim.getName());
    }

    @Override
    protected boolean checkParameters() throws BdfInstructionException {
        albumDim = BdfInstructionUtils.getMandatoryAlbumDim(fichotheque, requestMap);
        checkSubsetAdmin(albumDim.getAlbumMetadata().getAlbum());
        String dimType = albumDim.getDimType();
        if (AlbumUtils.needWidth(dimType)) {
            String widthString = getMandatory(ALBUMDIM_WIDTH_PARAMNAME);
            widthString = widthString.trim();
            if (widthString.length() == 0) {
                setError("_ error.empty.width");
                return false;
            }
            try {
                width = Integer.parseInt(widthString);
                if (width < 1) {
                    setError("_ error.wrong.width", widthString);
                    return false;
                }
            } catch (NumberFormatException nfe) {
                setError("_ error.wrong.width", widthString);
                return false;
            }

        }
        if (AlbumUtils.needHeight(dimType)) {
            String heightString = getMandatory(ALBUMDIM_HEIGHT_PARAMNAME);
            heightString = heightString.trim();
            if (heightString.length() == 0) {
                setError("_ error.empty.height");
                return false;
            }
            try {
                height = Integer.parseInt(heightString);
                if (height < 1) {
                    setError("_ error.wrong.height", heightString);
                    return false;
                }
            } catch (NumberFormatException nfe) {
                setError("_ error.wrong.height", heightString);
                return false;
            }

        }
        return true;
    }

}
