/* BdfServer_Commands - Copyright (c) 2010-2021 Vincent Calame - Exemole
 * Logiciel libre donné sous triple licence :
 * 1) selon les termes de la CeCILL V2
 * 2) selon les termes de l’EUPL V.1.1
 * 3) selon les termes de la GNU GPLv3
 * Voir le fichier licences.txt
 */


package fr.exemole.bdfserver.commands.configuration;

import fr.exemole.bdfserver.api.BdfServer;
import fr.exemole.bdfserver.api.BdfServerEditor;
import fr.exemole.bdfserver.api.groups.GroupDef;
import fr.exemole.bdfserver.api.instruction.BdfInstructionException;
import fr.exemole.bdfserver.commands.BdfCommandUtils;
import fr.exemole.bdfserver.tools.BdfServerUtils;
import fr.exemole.bdfserver.tools.instruction.AbstractBdfCommand;
import net.fichotheque.tools.parsers.AttributeParser;
import net.mapeadores.util.attr.AttributeChange;
import net.mapeadores.util.request.RequestMap;
import net.mapeadores.util.text.LabelChange;
import net.mapeadores.util.text.StringUtils;


/**
 *
 * @author Vincent Calame
 */
public class GroupCreationCommand extends AbstractBdfCommand {

    public final static String COMMANDNAME = "GroupCreation";
    public final static String COMMANDKEY = "_ CNF-10";
    public final static String NAME_PARAMNAME = "name";
    public final static String TITLE_PARAMPREFIX = "title/";
    public final static String ATTRIBUTES_PARAMNAME = "attributes";
    private String name;
    private LabelChange groupLabelChange;
    private AttributeChange attributeChange;

    public GroupCreationCommand(BdfServer bdfServer, RequestMap requestMap) {
        super(bdfServer, requestMap);
    }

    @Override
    public boolean needSynchronisation() {
        return true;
    }

    @Override
    protected void doCommand() throws BdfInstructionException {
        BdfServerEditor bdfServerEditor = bdfServer.getBdfServerEditor();
        GroupDef groupDef = bdfServerEditor.createGroupDef(name);
        BdfServerUtils.changeLabels(bdfServerEditor, groupDef, groupLabelChange);
        if (attributeChange != null) {
            BdfServerUtils.changeAttributes(bdfServerEditor, groupDef, attributeChange);
        }
        bdfServerEditor.saveChanges();
        setDone("_ done.configuration.groupcreation", name);

    }

    @Override
    protected boolean checkParameters() throws BdfInstructionException {
        checkGlobalAdmin();
        name = getMandatory(NAME_PARAMNAME);
        if (!StringUtils.isTechnicalName(name, true)) {
            setError("_ error.wrong.groupname", name);
            return false;
        }
        if (bdfServer.getGroupManager().getGroupDef(name) != null) {
            setError("_ error.existing.group", name);
            return false;
        }
        groupLabelChange = BdfCommandUtils.getLabelChange(requestMap, TITLE_PARAMPREFIX, true);
        String attributes = requestMap.getParameter(ATTRIBUTES_PARAMNAME);
        if (attributes != null) {
            attributeChange = AttributeParser.parse(attributes);
        }
        return true;
    }

}
