/* BdfServer_DirectoryStorage - Copyright (c) 2013-2022 Vincent Calame - Exemole
 * Logiciel libre donné sous triple licence :
 * 1) selon les termes de la CeCILL V2
 * 2) selon les termes de l’EUPL V.1.1
 * 3) selon les termes de la GNU GPLv3
 * Voir le fichier licences.txt
 */


package fr.exemole.bdfserver.storage.directory.bdfdata;

import net.fichotheque.EditOrigin;
import net.fichotheque.Subset;
import net.fichotheque.SubsetKey;
import net.fichotheque.addenda.Addenda;
import net.fichotheque.album.Album;
import net.fichotheque.corpus.Corpus;
import net.fichotheque.croisement.CroisementKey;
import net.fichotheque.sphere.Sphere;
import net.fichotheque.thesaurus.Thesaurus;


/**
 *
 * @author Vincent Calame
 */
public final class Remove {

    private Remove() {
    }

    public static void removeAddenda(BdfdataDirectories bdfDirectories, SubsetKey addendaKey, EditOrigin editOrigin) {
        StorageFile metadataStorageFile = BdfStorageUtils.getAddendaMetadataStorageFile(bdfDirectories, addendaKey);
        metadataStorageFile.archiveAndDelete(editOrigin);
        StorageFile directoryStorageFile = BdfStorageUtils.getAddendaDirectory(bdfDirectories, addendaKey);
        directoryStorageFile.delete();
    }

    public static void removeAlbum(BdfdataDirectories bdfDirectories, SubsetKey albumKey, EditOrigin editOrigin) {
        StorageFile metadataStorageFile = BdfStorageUtils.getAlbumMetadataStorageFile(bdfDirectories, albumKey);
        metadataStorageFile.archiveAndDelete(editOrigin);
        StorageFile directoryStorageFile = BdfStorageUtils.getAlbumDirectory(bdfDirectories, albumKey);
        directoryStorageFile.delete();
    }

    public static void removeCorpus(BdfdataDirectories bdfDirectories, SubsetKey corpusKey, Subset masterSubset, EditOrigin editOrigin) {
        SubsetKey masterSubsetKey = null;
        if (masterSubset != null) {
            masterSubsetKey = masterSubset.getSubsetKey();
        }
        StorageFile metadataStorageFile = BdfStorageUtils.getCorpusMetadataStorageFile(bdfDirectories, corpusKey, masterSubsetKey);
        metadataStorageFile.archiveAndDelete(editOrigin);
        StorageFile directoryStorageFile = BdfStorageUtils.getCorpusDirectory(bdfDirectories, corpusKey);
        directoryStorageFile.delete();
    }

    public static void removeSphere(BdfdataDirectories bdfDirectories, SubsetKey sphereKey, EditOrigin editOrigin) {
        StorageFile listStorageFile = BdfStorageUtils.getSphereListStorageFile(bdfDirectories, sphereKey);
        listStorageFile.archiveAndDelete(editOrigin);
        StorageFile metadataStorageFile = BdfStorageUtils.getSphereMetadataStorageFile(bdfDirectories, sphereKey);
        metadataStorageFile.archiveAndDelete(editOrigin);
        StorageFile directoryStorageFile = BdfStorageUtils.getSphereDirectory(bdfDirectories, sphereKey);
        directoryStorageFile.delete();
    }

    public static void removeThesaurus(BdfdataDirectories bdfDirectories, SubsetKey thesaurusKey, EditOrigin editOrigin) {
        StorageFile treeStorageFile = BdfStorageUtils.getThesaurusTreeStorageFile(bdfDirectories, thesaurusKey);
        treeStorageFile.archiveAndDelete(editOrigin);
        StorageFile metadataStorageFile = BdfStorageUtils.getThesaurusMetadataStorageFile(bdfDirectories, thesaurusKey);
        metadataStorageFile.archiveAndDelete(editOrigin);
        StorageFile directoryStorageFile = BdfStorageUtils.getThesaurusDirectory(bdfDirectories, thesaurusKey);
        directoryStorageFile.delete();
    }

    public static void removeDocument(BdfdataDirectories bdfDirectories, Addenda addenda, int id, EditOrigin editOrigin) {
        SubsetKey addendaKey = addenda.getSubsetKey();
        StorageFile storageFile = DocumentDirectory.getDocumentStorageFile(bdfDirectories, addendaKey, id);
        storageFile.archiveAndDelete(editOrigin);
        DocumentDirectory documentDirectory = DocumentDirectory.getDocumentDirectory(bdfDirectories, addendaKey, id);
        documentDirectory.delete();
    }

    public static void removeIllustration(BdfdataDirectories bdfDirectories, Album album, int id, EditOrigin editOrigin) {
        SubsetKey albumKey = album.getSubsetKey();
        StorageFile storageFile = IllustrationDirectory.getIllustrationStorageFile(bdfDirectories, albumKey, id);
        storageFile.archiveAndDelete(editOrigin);
        IllustrationDirectory illustrationDirectory = IllustrationDirectory.getIllustrationDirectory(bdfDirectories, albumKey, id);
        illustrationDirectory.delete();
    }

    public static void removeFiche(BdfdataDirectories bdfDirectories, Corpus corpus, int id, EditOrigin editOrigin) {
        SubsetKey subsetKey = corpus.getSubsetKey();
        StorageFile ficheStorageFile = FicheDirectory.getFicheStorageFile(bdfDirectories, subsetKey, id);
        ficheStorageFile.archiveAndDelete(editOrigin);
        StorageFile attributesStorageFile = FicheDirectory.getAttributesStorageFile(bdfDirectories, subsetKey, id);
        attributesStorageFile.archiveAndDelete(editOrigin);
        StorageFile chronoStorageFile = FicheDirectory.getChronoStorageFile(bdfDirectories, subsetKey, id);
        chronoStorageFile.archiveAndDelete(editOrigin);
        FicheDirectory ficheDirectory = FicheDirectory.getFicheDirectory(bdfDirectories, subsetKey, id);
        ficheDirectory.delete();
    }

    public static void removeMotcle(BdfdataDirectories bdfDirectories, Thesaurus thesaurus, int id, EditOrigin editOrigin) {
        StorageFile storageFile = BdfStorageUtils.getMotcleStorageFile(bdfDirectories, thesaurus.getSubsetKey(), id);
        storageFile.archiveAndDelete(editOrigin);
    }

    public static void removeRedacteur(BdfdataDirectories bdfDirectories, Sphere sphere, int id, EditOrigin editOrigin) {
        StorageFile storageFile = BdfStorageUtils.getRedacteurStorageFile(bdfDirectories, sphere.getSubsetKey(), id);
        storageFile.archiveAndDelete(editOrigin);
    }

    public static void removeCroisement(BdfdataDirectories bdfDirectories, CroisementKey croisementKey, EditOrigin editOrigin) {
        StorageFile storageFile = BdfStorageUtils.getCroisementStorageFile(bdfDirectories, croisementKey);
        storageFile.archiveAndDelete(editOrigin);
    }

}
