/* BdfServer_Html - Copyright (c) 2020 Vincent Calame - Exemole
 * Logiciel libre donné sous triple licence :
 * 1) selon les termes de la CeCILL V2
 * 2) selon les termes de l’EUPL V.1.1
 * 3) selon les termes de la GNU GPLv3
 * Voir le fichier licences.txt
 */


package fr.exemole.bdfserver.html.consumers;

import java.util.function.Consumer;
import net.mapeadores.util.html.ConsumerFactory;
import net.mapeadores.util.html.HA;
import net.mapeadores.util.html.HtmlAttributes;
import net.mapeadores.util.html.HtmlConstants;
import net.mapeadores.util.html.HtmlPrinter;
import net.mapeadores.util.html.HtmlWrapper;
import net.mapeadores.util.html.WrapperFactory;
import net.mapeadores.util.localisation.LocalisationUtils;
import net.mapeadores.util.localisation.Message;


/**
 *
 * @author Vincent Calame
 */
public class Button implements Consumer<HtmlPrinter> {

    public final static HtmlWrapper COMMAND = WrapperFactory.div("command-Submit");
    public final static Consumer<HtmlPrinter> ICON = ConsumerFactory.span("global-button-Icon");
    private final static String LINK_TYPE = "link";
    private final String type;
    private String href;
    private String target;
    private String titleLocKey;
    private String title;
    private Message titleMessage;
    private String tooltipLocKey;
    private String tooltip;
    private Message tooltipMessage;
    private String action;
    private String formId;
    private boolean ficheForm;

    private Button(String type) {
        this.type = type;
    }

    public Button action(String action) {
        this.action = action;
        return this;
    }

    public Button href(CharSequence href) {
        this.href = href.toString();
        return this;
    }

    public Button formId(String formId) {
        this.formId = formId;
        return this;
    }

    public Button ficheForm(boolean ficheForm) {
        this.ficheForm = ficheForm;
        return this;
    }

    public Button target(String target) {
        this.target = target;
        return this;
    }

    public Button title(String title) {
        this.title = title;
        return this;
    }

    public Button titleMessage(String titleLocKey) {
        this.titleLocKey = titleLocKey;
        return this;
    }

    public Button titleMessage(String titleLocKey, Object... values) {
        this.titleMessage = LocalisationUtils.toMessage(titleLocKey, values);
        return this;
    }

    public Button titleMessage(Message titleMessage) {
        this.titleMessage = titleMessage;
        return this;
    }

    public Button tooltip(String tooltip) {
        this.tooltip = tooltip;
        return this;
    }

    public Button tooltipMessage(String tooltipLocKey) {
        this.tooltipLocKey = tooltipLocKey;
        return this;
    }

    public Button tooltipMessage(String tooltipLocKey, Object... values) {
        this.tooltipMessage = LocalisationUtils.toMessage(tooltipLocKey, values);
        return this;
    }

    public Button tooltipMessage(Message tooltipMessage) {
        this.tooltipMessage = tooltipMessage;
        return this;
    }

    public static Button submit() {
        return new Button(HtmlConstants.SUBMIT_TYPE);
    }

    public static Button submit(String titleLocKey) {
        return new Button(HtmlConstants.SUBMIT_TYPE).titleMessage(titleLocKey);
    }

    public static Button submit(String action, String titleLocKey) {
        return (new Button(HtmlConstants.SUBMIT_TYPE)).titleMessage(titleLocKey).action(action);
    }

    public static Button link() {
        return new Button(LINK_TYPE);
    }

    public static Button link(String href) {
        return new Button(LINK_TYPE).href(href);
    }

    @Override
    public void accept(HtmlPrinter hp) {
        if (type.equals(LINK_TYPE)) {
            acceptLink(hp);
        } else {
            acceptButton(hp);
        }
    }

    private void acceptButton(HtmlPrinter hp) {
        HtmlAttributes buttonAttributes = HA.type(type).classes("global-button-Standard").addClass((action != null), action);
        checkTitle(hp, buttonAttributes);
        if (formId != null) {
            buttonAttributes.attr("form", formId);
        }
        if (ficheForm) {
            buttonAttributes.attr("data-ficheform-role", "submit-button");
        }
        hp
                .BUTTON(buttonAttributes);
        checkIcon(hp);
        checkText(hp);
        hp
                ._BUTTON();
    }

    private void acceptLink(HtmlPrinter hp) {
        HtmlAttributes linkAttributes = HA.href(href).target(target).classes("global-button-Link").addClass((action != null), action);
        checkTitle(hp, linkAttributes);
        hp
                .A(linkAttributes);
        checkIcon(hp);
        checkText(hp);
        hp
                ._A();
    }

    private void checkTitle(HtmlPrinter hp, HtmlAttributes htmlAttributes) {
        if (tooltipLocKey != null) {
            htmlAttributes.titleLocKey(tooltipLocKey);
        } else if (tooltip != null) {
            htmlAttributes.title(tooltip);
        } else if (tooltipMessage != null) {
            htmlAttributes.title(hp.getLocalization(tooltipMessage));
        }
    }

    private void checkText(HtmlPrinter hp) {
        if (titleLocKey != null) {
            hp
                    .SPAN("global-button-Text")
                    .__localize(titleLocKey)
                    ._SPAN();
        } else if (title != null) {
            hp
                    .SPAN("global-button-Text")
                    .__escape(title)
                    ._SPAN();
        } else if (titleMessage != null) {
            hp
                    .SPAN("global-button-Text")
                    .__localize(titleMessage)
                    ._SPAN();
        }
    }

    private void checkIcon(HtmlPrinter hp) {
        if (action != null) {
            hp
                    .__(Button.ICON);
        }
    }

}
