/* BdfServer_HtmlProducers - Copyright (c) 2011-2022 Vincent Calame - Exemole
 * Logiciel libre donné sous triple licence :
 * 1) selon les termes de la CeCILL V2
 * 2) selon les termes de l’EUPL V.1.1
 * 3) selon les termes de la GNU GPLv3
 * Voir le fichier licences.txt
 */


package fr.exemole.bdfserver.htmlproducers.corpus;

import fr.exemole.bdfserver.api.instruction.BdfParameters;
import fr.exemole.bdfserver.api.interaction.Domains;
import fr.exemole.bdfserver.api.interaction.InteractionConstants;
import fr.exemole.bdfserver.api.interaction.domains.CorpusDomain;
import fr.exemole.bdfserver.api.roles.PermissionSummary;
import fr.exemole.bdfserver.html.BdfHtmlUtils;
import fr.exemole.bdfserver.html.BdfServerHtmlProducer;
import fr.exemole.bdfserver.html.jslib.CommonJsLibs;
import net.fichotheque.corpus.Corpus;
import net.mapeadores.util.html.CommandBox;


/**
 *
 * @author Vincent Calame
 */
public class CorpusAdvancedCommandsHtmlProducer extends BdfServerHtmlProducer {

    private final PermissionSummary permissionSummary;
    private final Corpus corpus;

    public CorpusAdvancedCommandsHtmlProducer(BdfParameters bdfParameters, Corpus corpus) {
        super(bdfParameters);
        this.permissionSummary = bdfParameters.getPermissionSummary();
        this.corpus = corpus;
        addJsLib(CommonJsLibs.COMMANDTEST);
        addJsLib(CommonJsLibs.SUBSETCHANGE);
        addJsLib(CommonJsLibs.DEPLOY);
        addJsLib(CommonJsLibs.CODEMIRRORMODE);
        addThemeCss("corpus.css");
    }

    @Override
    public void printHtml() {
        start();
        BdfHtmlUtils.printSubsetHeader(this, bdfServer, bdfUser, permissionSummary, corpus, CorpusDomain.CORPUS_ADVANCEDCOMMANDS_PAGE);
        CorpusHtmlUtils.printCorpusToolbar(this, corpus, CorpusDomain.CORPUS_ADVANCEDCOMMANDS_PAGE);
        printCommandMessageUnit();
        CommandBox commandBox = CommandBox.init()
                .action(Domains.CORPUS)
                .family("CRP");
        if ((permissionSummary.isGlobalAdmin()) && (corpus.isRemoveable())) {
            commandBox
                    .errorPage(CorpusDomain.CORPUS_ADVANCEDCOMMANDS_PAGE)
                    .page(InteractionConstants.MESSAGE_PAGE);
            CorpusCommandBoxUtils.printCorpusRemoveBox(this, commandBox, corpus);
        }
        commandBox
                .errorPage(null)
                .page(CorpusDomain.CORPUS_ADVANCEDCOMMANDS_PAGE);
        CorpusCommandBoxUtils.printCorpusAttributeChangeBox(this, commandBox, corpus);
        commandBox
                .errorPage(CorpusDomain.CORPUS_ADVANCEDCOMMANDS_PAGE)
                .page(CorpusDomain.DUPLICATIONLOG_PAGE);
        CorpusCommandBoxUtils.printDuplicationBox(this, commandBox, corpus, bdfServer, workingLang);
        commandBox
                .errorPage(null)
                .page(CorpusDomain.CORPUS_ADVANCEDCOMMANDS_PAGE);
        CorpusCommandBoxUtils.printReloadBox(this, commandBox, corpus);
        commandBox
                .errorPage(CorpusDomain.CORPUS_ADVANCEDCOMMANDS_PAGE)
                .page(CorpusDomain.CORPUS_PHRASESFORM_PAGE);
        CorpusCommandBoxUtils.printCloneBox(this, commandBox, corpus, bdfServer, workingLang);
        commandBox
                .errorPage(null)
                .page(CorpusDomain.CORPUS_ADVANCEDCOMMANDS_PAGE);
        CorpusCommandBoxUtils.printConversionBox(this, commandBox, corpus, workingLang);
        commandBox
                .errorPage(CorpusDomain.CORPUS_ADVANCEDCOMMANDS_PAGE)
                .page(CorpusDomain.REPONDERATIONLOG_PAGE);
        CorpusCommandBoxUtils.printReponderationBox(this, commandBox, corpus);
        commandBox
                .errorPage(null)
                .page(CorpusDomain.CORPUS_ADVANCEDCOMMANDS_PAGE);
        CorpusCommandBoxUtils.printImageToIllustrationBox(this, commandBox, corpus, bdfServer, workingLang);
        end();
    }

}
