/* BdfServer_HtmlProducers - Copyright (c) 2011-2019 Vincent Calame - Exemole
 * Logiciel libre donné sous triple licence :
 * 1) selon les termes de la CeCILL V2
 * 2) selon les termes de l’EUPL V.1.1
 * 3) selon les termes de la GNU GPLv3
 * Voir le fichier licences.txt
 */


package fr.exemole.bdfserver.htmlproducers.pioche;

import java.util.List;
import net.fichotheque.Subset;
import net.fichotheque.SubsetKey;
import net.mapeadores.util.html.HtmlPrinter;
import net.mapeadores.util.html.JsObject;


/**
 *
 * @author Vincent Calame
 */
public final class PiocheHtmlUtils {

    private PiocheHtmlUtils() {
    }

    public static String getSubsetsString(List<Subset> subsetList) {
        if (subsetList == null) {
            return "";
        }
        StringBuilder buf = new StringBuilder();
        int size = subsetList.size();
        for (int i = 0; i < size; i++) {
            Subset subset = subsetList.get(i);
            if (i > 0) {
                buf.append(",");
            }
            buf.append(subset.getSubsetName());
        }
        return buf.toString();
    }

    public static boolean printJsObject(HtmlPrinter hp, String clientId, PiocheParameters piocheParameters, int total, String separator, String wanted, String json, String subsetsString, String param) {
        JsObject args = JsObject.init()
                .put("clientId", clientId)
                .put("appelant", piocheParameters.getAppelant())
                .put("limit", piocheParameters.getLimit())
                .put("separator", separator)
                .put("count", total)
                .put("wanted", wanted)
                .put("croisement", checkObject((SubsetKey) piocheParameters.getParameter(PiocheParameters.CROISEMENT)))
                .put("json", json)
                .put("subsets", subsetsString)
                .put("param", param)
                .put("motcleselectoptions", piocheParameters.getParameter(PiocheParameters.MOTCLESELECTOPTIONS));
        hp
                .SCRIPT()
                .__jsObject("Pioche.ARGS", args)
                ._SCRIPT();
        return true;
    }

    private static String checkObject(Object obj) {
        if (obj == null) {
            return null;
        } else {
            return obj.toString();
        }
    }

}
