/* BdfServer_Multi - Copyright (c) 2015-2021 Vincent Calame - Exemole
 * Logiciel libre donné sous triple licence :
 * 1) selon les termes de la CeCILL V2
 * 2) selon les termes de l’EUPL V.1.1
 * 3) selon les termes de la GNU GPLv3
 * Voir le fichier licences.txt
 */


package fr.exemole.bdfserver.multi;

import fr.exemole.bdfserver.multi.commands.AbstractMultiCommand;
import fr.exemole.bdfserver.multi.commands.FichothequeCreationCommand;
import fr.exemole.bdfserver.multi.commands.FichothequeDuplicationCommand;
import fr.exemole.bdfserver.multi.commands.FichothequeInitCommand;
import fr.exemole.bdfserver.multi.commands.PersonAddCommand;
import fr.exemole.bdfserver.multi.commands.PersonChangeCommand;
import net.mapeadores.util.logging.CommandMessage;
import net.mapeadores.util.logging.ErrorMessageException;
import net.mapeadores.util.logging.LogUtils;
import net.mapeadores.util.request.RequestConstants;
import net.mapeadores.util.request.RequestMap;


/**
 *
 * @author Vincent Calame
 */
public final class MultiAdminCommands {

    private MultiAdminCommands() {

    }

    public static CommandMessage run(Multi multi, RequestMap requestMap) {
        String cmd = requestMap.getParameter(RequestConstants.COMMAND_PARAMETER);
        if (cmd == null) {
            return null;
        }
        AbstractMultiCommand command = getCommand(multi, requestMap, cmd);
        if (command == null) {
            return LogUtils.error("_ error.unknown.parametervalue", "cmd", cmd);
        } else {
            try {
                return command.doCommand();
            } catch (ErrorMessageException eme) {
                return eme.getErrorMessage();
            }
        }
    }

    private static AbstractMultiCommand getCommand(Multi multi, RequestMap requestMap, String cmd) {
        switch (cmd) {
            case FichothequeCreationCommand.COMMAND_NAME: {
                return new FichothequeCreationCommand(multi, requestMap);
            }
            case FichothequeDuplicationCommand.COMMAND_NAME: {
                return new FichothequeDuplicationCommand(multi, requestMap);
            }
            case FichothequeInitCommand.COMMAND_NAME: {
                return new FichothequeInitCommand(multi, requestMap);
            }
            case PersonChangeCommand.COMMAND_NAME: {
                return new PersonChangeCommand(multi, requestMap);
            }
            case PersonAddCommand.COMMAND_NAME: {
                return new PersonAddCommand(multi, requestMap);
            }
            default:
                return null;
        }
    }

}
