/* BdfServer_Multi - Copyright (c) 2015-2022 Vincent Calame - Exemole
 * Logiciel libre donné sous triple licence :
 * 1) selon les termes de la CeCILL V2
 * 2) selon les termes de l’EUPL V.1.1
 * 3) selon les termes de la GNU GPLv3
 * Voir le fichier licences.txt
 */


package fr.exemole.bdfserver.multi.htmlproducers;

import fr.exemole.bdfserver.html.BdfHtmlProducer;
import fr.exemole.bdfserver.html.JsLibManager;
import fr.exemole.bdfserver.multi.Multi;
import fr.exemole.bdfserver.tools.storage.IconScanEngine;
import net.mapeadores.util.localisation.Lang;


/**
 *
 * @author Vincent Calame
 */
public abstract class MultiHtmlProducer extends BdfHtmlProducer {

    protected final Multi multi;
    private final Lang workingLang;

    public MultiHtmlProducer(Multi multi) {
        super(multi.getWebappsJsAnalyser(), multi.getBuildInfo());
        setWithJavascript(true);
        this.multi = multi;
        this.workingLang = multi.getMultiConf().getLang();
        scanIcons();
        setReversePath("_rsc/");
        addMessageLocalisation(multi.getMultiConf().getMessageLocalisation());
        setBodyCssClass("global-body-Default");
    }

    public MultiHtmlProducer(Multi multi, Lang lang) {
        super(multi.getWebappsJsAnalyser(), multi.getBuildInfo());
        this.multi = multi;
        this.workingLang = lang;
        scanIcons();
        setReversePath("_rsc/");
        addMessageLocalisation(multi.getMultiConf().getMessageLocalisation(lang));
    }

    @Override
    public void start(String title) {
        resolveJavascript();
        resolveCss();
        setIcons();
        super.start(workingLang, title);
    }

    @Override
    public void end() {
        JsLibManager jsLibManager = getJsLibManager();
        if (jsLibManager != null) {
            jsLibManager.end(this, multi.getWebappsResourceStorages(), workingLang);
        }
        super.end();
    }

    private void scanIcons() {
        setSupplementaryIconAttributesList(IconScanEngine.run(multi.getWebappsResourceStorages(), multi.getMimeTypeResolver()));
    }

}
