/* FichothequeLib_Tools - Copyright (c) 2014-2018 Vincent Calame - Exemole
 * Logiciel libre donné sous triple licence :
 * 1) selon les termes de la CeCILL V2
 * 2) selon les termes de l’EUPL V.1.1
 * 3) selon les termes de la GNU GPLv3
 * Voir le fichier licences.txt
 */


package net.fichotheque.tools.dom;

import net.fichotheque.corpus.CorpusEditor;
import net.fichotheque.corpus.FicheMeta;
import net.mapeadores.util.logging.MessageHandler;
import net.mapeadores.util.xml.DOMUtils;
import net.mapeadores.util.xml.DomMessages;
import net.mapeadores.util.xml.ElementHandler;
import org.w3c.dom.Element;


/**
 *
 * @author Vincent Calame
 */
public class AttributesDOMReader {

    private final MessageHandler messageHandler;
    private final AttributeDOMReader attributeDOMReader;
    private final RootHandler rootHandler = new RootHandler();

    public AttributesDOMReader(CorpusEditor corpusEditor, MessageHandler messageHandler) {
        this.messageHandler = messageHandler;
        this.attributeDOMReader = new AttributeDOMReader(corpusEditor.getFichothequeEditor(), messageHandler);
    }

    public void fillFicheMeta(FicheMeta ficheMeta, Element element) {
        rootHandler.setFicheMeta(ficheMeta);
        DOMUtils.readChildren(element, rootHandler);
    }


    private class RootHandler implements ElementHandler {

        private FicheMeta ficheMeta;

        private RootHandler() {
        }

        private void setFicheMeta(FicheMeta ficheMeta) {
            this.ficheMeta = ficheMeta;
        }

        @Override
        public void readElement(Element element) {
            String tagName = element.getTagName();
            if (tagName.equals("attr")) {
                attributeDOMReader.readAttrElement(element, ficheMeta, tagName);
            } else {
                DomMessages.unknownTagWarning(messageHandler, tagName);
            }
        }

    }

}
