/* FichothequeLib_Tools - Copyright (c) 2011-2021 Vincent Calame - Exemole
 * Logiciel libre donné sous triple licence :
 * 1) selon les termes de la CeCILL V2
 * 2) selon les termes de l’EUPL V.1.1
 * 3) selon les termes de la GNU GPLv3
 * Voir le fichier licences.txt
 */


package net.fichotheque.tools.extraction.builders;

import java.util.Collections;
import java.util.List;
import net.fichotheque.extraction.ExtractionConstants;
import net.fichotheque.extraction.def.DocumentFilter;
import net.fichotheque.extraction.def.ExtraitAddendaDef;
import net.fichotheque.selection.DocumentCondition;
import net.fichotheque.utils.SelectionUtils;


/**
 *
 * @author Vincent Calame
 */
public class ExtraitAddendaDefBuilder {

    private DocumentFilter documentFilter;
    private String extraitName = null;
    private String tagName = ExtractionConstants.EXTRAITADDENDA_DEFAULT_TAGNAME;
    private List<DocumentCondition.Entry> entryList = SelectionUtils.EMPTY_DOCUMENTCONDITIONENTRYLIST;

    public ExtraitAddendaDefBuilder(DocumentFilter documentFilter) {
        if (documentFilter == null) {
            throw new IllegalArgumentException("documentFilter is null");
        }
        this.documentFilter = documentFilter;
    }

    public ExtraitAddendaDefBuilder setDocumentFilter(DocumentFilter DocumentFilter) {
        if (documentFilter == null) {
            throw new IllegalArgumentException("documentFilter is null");
        }
        this.documentFilter = DocumentFilter;
        return this;
    }

    public ExtraitAddendaDefBuilder setExtraitName(String extraitName) {
        if ((extraitName != null) && (extraitName.length() == 0)) {
            extraitName = null;
        }
        this.extraitName = extraitName;
        return this;
    }

    public ExtraitAddendaDefBuilder setTagName(String tagName) {
        this.tagName = BuilderUtils.testTagName(tagName, ExtractionConstants.EXTRAITADDENDA_DEFAULT_TAGNAME);
        return this;
    }

    public ExtraitAddendaDefBuilder setEntryList(List<DocumentCondition.Entry> list) {
        this.entryList = list;
        return this;
    }

    public ExtraitAddendaDefBuilder setEntryList(DocumentCondition.Entry entry) {
        this.entryList = Collections.singletonList(entry);
        return this;
    }

    public ExtraitAddendaDef toExtraitAddendaDef() {
        return new InternalExtraitAddendaDef(documentFilter, extraitName, tagName, entryList);
    }

    public static ExtraitAddendaDefBuilder init(DocumentFilter documentFilter) {
        return new ExtraitAddendaDefBuilder(documentFilter);
    }


    private static class InternalExtraitAddendaDef implements ExtraitAddendaDef {

        private final DocumentFilter documentFilter;
        private final String extraitName;
        private final String tagName;
        private final List<DocumentCondition.Entry> entryList;

        private InternalExtraitAddendaDef(DocumentFilter documentFilter, String extraitName, String tagName, List<DocumentCondition.Entry> entryList) {
            this.tagName = tagName;
            this.extraitName = extraitName;
            this.documentFilter = documentFilter;
            this.entryList = entryList;
        }

        @Override
        public String getTagName() {
            return tagName;
        }

        @Override
        public String getExtraitName() {
            return extraitName;
        }

        @Override
        public DocumentFilter getDocumentFilter() {
            return documentFilter;
        }

        @Override
        public List<DocumentCondition.Entry> getEntryList() {
            return entryList;
        }

    }

}
