/* FichothequeLib_Tools - Copyright (c) 2011-2021 Vincent Calame - Exemole
 * Logiciel libre donné sous triple licence :
 * 1) selon les termes de la CeCILL V2
 * 2) selon les termes de l’EUPL V.1.1
 * 3) selon les termes de la GNU GPLv3
 * Voir le fichier licences.txt
 */


package net.fichotheque.tools.extraction.builders;

import java.util.Collections;
import java.util.List;
import net.fichotheque.extraction.ExtractionConstants;
import net.fichotheque.extraction.def.ExtraitCorpusDef;
import net.fichotheque.extraction.def.FicheFilter;
import net.fichotheque.extraction.def.GroupClause;
import net.fichotheque.extraction.def.IntituleClause;
import net.fichotheque.extraction.def.PackClause;
import net.fichotheque.selection.FicheCondition;
import net.fichotheque.utils.SelectionUtils;


/**
 *
 * @author Vincent Calame
 */
public class ExtraitCorpusDefBuilder {

    private FicheFilter ficheFilter;
    private String extraitName = null;
    private String tagName = ExtractionConstants.EXTRAITCORPUS_DEFAULT_TAGNAME;
    private List<FicheCondition.Entry> ficheQueryList = SelectionUtils.EMPTY_FICHECONDITIONENTRYLIST;
    private GroupClause groupClause = null;
    private PackClause packClause = null;
    private IntituleClause intituleClause = null;
    private boolean descendantAxis;
    private boolean master;

    public ExtraitCorpusDefBuilder(FicheFilter ficheFilter) {
        if (ficheFilter == null) {
            throw new IllegalArgumentException("ficheFilter is null");
        }
        this.ficheFilter = ficheFilter;
    }

    public ExtraitCorpusDefBuilder setFicheFilter(FicheFilter ficheFilter) {
        if (ficheFilter == null) {
            throw new IllegalArgumentException("ficheFilter is null");
        }
        this.ficheFilter = ficheFilter;
        return this;
    }

    public ExtraitCorpusDefBuilder setExtraitName(String extraitName) {
        if ((extraitName != null) && (extraitName.length() == 0)) {
            extraitName = null;
        }
        this.extraitName = extraitName;
        return this;
    }

    public ExtraitCorpusDefBuilder setTagName(String tagName) {
        this.tagName = BuilderUtils.testTagName(tagName, ExtractionConstants.EXTRAITCORPUS_DEFAULT_TAGNAME);
        return this;
    }

    public ExtraitCorpusDefBuilder setEntryList(List<FicheCondition.Entry> list) {
        this.ficheQueryList = list;
        return this;
    }

    public ExtraitCorpusDefBuilder setEntryList(FicheCondition.Entry ficheQuery) {
        this.ficheQueryList = Collections.singletonList(ficheQuery);
        return this;
    }

    public ExtraitCorpusDefBuilder setMaster(boolean master) {
        this.master = master;
        return this;
    }

    public ExtraitCorpusDefBuilder setGroupClause(GroupClause groupClause) {
        this.groupClause = groupClause;
        return this;
    }

    public ExtraitCorpusDefBuilder setPackClause(PackClause packClause) {
        this.packClause = packClause;
        return this;
    }

    public ExtraitCorpusDefBuilder setIntituleClause(IntituleClause intituleClause) {
        this.intituleClause = intituleClause;
        return this;
    }

    public ExtraitCorpusDefBuilder setDescendantAxis(boolean descendantAxis) {
        this.descendantAxis = descendantAxis;
        return this;
    }

    public ExtraitCorpusDef toExtraitCorpusDef() {
        return new InternalExtraitCorpusDef(ficheFilter, extraitName, tagName, ficheQueryList, master, groupClause, packClause, intituleClause, descendantAxis);
    }

    public static ExtraitCorpusDefBuilder init(FicheFilter ficheFilter) {
        return new ExtraitCorpusDefBuilder(ficheFilter);
    }


    private static class InternalExtraitCorpusDef implements ExtraitCorpusDef {

        private final FicheFilter ficheFilter;
        private final String extraitName;
        private final String tagName;
        private final List<FicheCondition.Entry> entryList;
        private final boolean master;
        private final GroupClause groupClause;
        private final PackClause packClause;
        private final IntituleClause intituleClause;

        private final boolean descendantAxis;


        private InternalExtraitCorpusDef(FicheFilter ficheFilter, String extraitName, String tagName, List<FicheCondition.Entry> entryList, boolean master, GroupClause groupClause,
                PackClause packClause, IntituleClause intituleClause, boolean descendantAxis) {
            this.ficheFilter = ficheFilter;
            this.extraitName = extraitName;
            this.tagName = tagName;
            this.entryList = entryList;
            this.master = master;
            this.groupClause = groupClause;
            this.packClause = packClause;
            this.intituleClause = intituleClause;
            this.descendantAxis = descendantAxis;
        }

        @Override
        public String getTagName() {
            return tagName;
        }

        @Override
        public boolean isMaster() {
            return master;
        }

        @Override
        public GroupClause getGroupClause() {
            return groupClause;
        }

        @Override
        public PackClause getPackClause() {
            return packClause;
        }

        @Override
        public String getExtraitName() {
            return extraitName;
        }

        @Override
        public IntituleClause getIntituleClause() {
            return intituleClause;
        }

        @Override
        public FicheFilter getFicheFilter() {
            return ficheFilter;
        }

        @Override
        public List<FicheCondition.Entry> getEntryList() {
            return entryList;
        }

        @Override
        public boolean isDescendantAxis() {
            return descendantAxis;
        }

    }

}
