/* FichothequeLib_Tools - Copyright (c) 2011-2018 Vincent Calame - Exemole
 * Logiciel libre donné sous triple licence :
 * 1) selon les termes de la CeCILL V2
 * 2) selon les termes de l’EUPL V.1.1
 * 3) selon les termes de la GNU GPLv3
 * Voir le fichier licences.txt
 */


package net.fichotheque.tools.extraction.builders;

import java.util.Collections;
import java.util.List;
import net.fichotheque.extraction.ExtractionConstants;
import net.fichotheque.extraction.def.ExtraitThesaurusDef;
import net.fichotheque.extraction.def.MotcleFilter;
import net.fichotheque.selection.MotcleCondition;
import net.fichotheque.utils.SelectionUtils;


/**
 *
 * @author Vincent Calame
 */
public class ExtraitThesaurusDefBuilder implements ExtractionConstants {

    private MotcleFilter motcleFilter;
    private String extraitName = null;
    private String tagName = EXTRAITTHESAURUS_DEFAULT_TAGNAME;
    private List<MotcleCondition.Entry> entryList = SelectionUtils.EMPTY_MOTCLECONDITIONENTRYLIST;
    private boolean master;

    public ExtraitThesaurusDefBuilder(MotcleFilter motcleFilter) {
        if (motcleFilter == null) {
            throw new IllegalArgumentException("motcleFilter is null");
        }
        this.motcleFilter = motcleFilter;
    }


    public ExtraitThesaurusDefBuilder setMotcleFilter(MotcleFilter motcleFilter) {
        if (motcleFilter == null) {
            throw new IllegalArgumentException("motcleFilter is null");
        }
        this.motcleFilter = motcleFilter;
        return this;
    }

    public ExtraitThesaurusDefBuilder setExtraitName(String extraitName) {
        if ((extraitName != null) && (extraitName.length() == 0)) {
            extraitName = null;
        }
        this.extraitName = extraitName;
        return this;
    }

    public ExtraitThesaurusDefBuilder setTagName(String tagName) {
        this.tagName = BuilderUtils.testTagName(tagName, EXTRAITTHESAURUS_DEFAULT_TAGNAME);
        return this;
    }

    public ExtraitThesaurusDefBuilder setEntryList(List<MotcleCondition.Entry> list) {
        this.entryList = list;
        return this;
    }

    public ExtraitThesaurusDefBuilder setEntryList(MotcleCondition.Entry entry) {
        this.entryList = Collections.singletonList(entry);
        return this;
    }

    public ExtraitThesaurusDefBuilder setMaster(boolean master) {
        this.master = master;
        return this;
    }

    public ExtraitThesaurusDef toExtraitThesaurusDef() {
        return new InternalExtraitThesaurusDef(motcleFilter, extraitName, tagName, entryList, master);
    }

    public static ExtraitThesaurusDefBuilder init(MotcleFilter motcleFilter) {
        return new ExtraitThesaurusDefBuilder(motcleFilter);
    }


    private static class InternalExtraitThesaurusDef implements ExtraitThesaurusDef {

        private final MotcleFilter motcleFilter;
        private final String extraitName;
        private final String tagName;
        private final List<MotcleCondition.Entry> entryList;
        private final boolean master;

        private InternalExtraitThesaurusDef(MotcleFilter motcleFilter, String extraitName, String tagName, List<MotcleCondition.Entry> entryList, boolean master) {
            this.motcleFilter = motcleFilter;
            this.extraitName = extraitName;
            this.tagName = tagName;
            this.entryList = entryList;
            this.master = master;
        }

        @Override
        public String getTagName() {
            return tagName;
        }

        @Override
        public String getExtraitName() {
            return extraitName;
        }

        @Override
        public boolean isMaster() {
            return master;
        }

        @Override
        public MotcleFilter getMotcleFilter() {
            return motcleFilter;
        }

        @Override
        public List<MotcleCondition.Entry> getEntryList() {
            return entryList;
        }

    }

}
