/* FichothequeLib_Tools - Copyright (c) 2010-2018 Vincent Calame - Exemole
 * Logiciel libre donné sous triple licence :
 * 1) selon les termes de la CeCILL V2
 * 2) selon les termes de l’EUPL V.1.1
 * 3) selon les termes de la GNU GPLv3
 * Voir le fichier licences.txt
 */


package net.fichotheque.tools.extraction.builders;

import net.fichotheque.extraction.ExtractionConstants;
import net.fichotheque.extraction.def.PackClause;


/**
 *
 * @author Vincent Calame
 */
public class PackClauseBuilder implements ExtractionConstants {

    private int packSize;
    private String tagName = PACK_DEFAULT_TAGNAME;
    private int modulo = 0;

    public PackClauseBuilder(int packSize) {
        if (packSize < 1) {
            packSize = 1;
        }
        this.packSize = packSize;
    }

    public PackClauseBuilder setTagName(String tagName) {
        this.tagName = BuilderUtils.testTagName(tagName, PACK_DEFAULT_TAGNAME);
        return this;
    }

    public PackClauseBuilder setModulo(int modulo) {
        if (modulo < 2) {
            modulo = 0;
        }
        this.modulo = modulo;
        return this;
    }

    public PackClause toPackClause() {
        return new InternalPackClause(tagName, packSize, modulo);
    }

    public static PackClauseBuilder init(int packSize) {
        return new PackClauseBuilder(packSize);
    }


    private static class InternalPackClause implements PackClause {

        private final String tagName;
        private final int packSize;
        private final int modulo;


        private InternalPackClause(String tagName, int packSize, int modulo) {
            this.tagName = tagName;
            this.packSize = packSize;
            this.modulo = modulo;
        }

        @Override
        public String getTagName() {
            return tagName;
        }

        @Override
        public int getModulo() {
            return modulo;
        }

        @Override
        public int getPackSize() {
            return packSize;
        }

    }

}
