/* FichothequeLib_Xml - Copyright (c) 2011-2022 Vincent Calame - Exemole
 * Logiciel libre donné sous triple licence :
 * 1) selon les termes de la CeCILL V2
 * 2) selon les termes de l’EUPL V.1.1
 * 3) selon les termes de la GNU GPLv3
 * Voir le fichier licences.txt
 */


package net.fichotheque.xml.exportation;

import java.io.IOException;
import net.fichotheque.exportation.sql.SqlExportDef;
import net.fichotheque.selection.FicheQuery;
import net.fichotheque.selection.FichothequeQuery;
import net.fichotheque.selection.MotcleQuery;
import net.fichotheque.xml.extraction.ExtractionXMLUtils;
import net.mapeadores.util.attr.AttributeUtils;
import net.mapeadores.util.text.LabelUtils;
import net.mapeadores.util.xml.XMLPart;
import net.mapeadores.util.xml.XMLWriter;


/**
 *
 * @author Vincent Calame
 */
public class SqlExportXMLPart extends XMLPart {

    public SqlExportXMLPart(XMLWriter xmlWriter) {
        super(xmlWriter);
    }

    public void addSqlExportDef(SqlExportDef sqlExportDef) throws IOException {
        openTag("sqlexport");
        LabelUtils.addLabels(this, sqlExportDef.getTitleLabels());
        addSimpleElement("tableexport-name", sqlExportDef.getTableExportName());
        addSimpleElement("sqlexport-classname", sqlExportDef.getSqlExportClassName());
        addSimpleElement("target-name", sqlExportDef.getTargetName());
        addSimpleElement("target-path", sqlExportDef.getTargetPath().toString());
        addSimpleElement("file-name", sqlExportDef.getFileName());
        addSimpleElement("post-command", sqlExportDef.getPostCommand());
        for (SqlExportDef.Param param : sqlExportDef.getParamList()) {
            startOpenTag("param");
            addAttribute("name", param.getName());
            addAttribute("value", param.getValue());
            closeEmptyTag();
        }
        FichothequeQuery fichothequeQuery = sqlExportDef.getCustomFichothequeQuery();
        for (FicheQuery ficheQuery : fichothequeQuery.getFicheQueryList()) {
            openTag("fiche-query");
            ExtractionXMLUtils.writeFicheQuery(this, ficheQuery, null);
            closeTag("fiche-query");
        }
        for (MotcleQuery motcleQuery : fichothequeQuery.getMotcleQueryList()) {
            openTag("motcle-query");
            ExtractionXMLUtils.writeMotcleQuery(this, motcleQuery, null);
            closeTag("motcle-query");
        }
        AttributeUtils.addAttributes(this, sqlExportDef.getAttributes());
        closeTag("sqlexport");
    }

}
